/*
** config.h - part of GrabURL 2.0
** Copyright (C) 1996-97 Serge Emond
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License
** as published by the Free Software Foundation; either version 2
** of the License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

#ifndef GU_CONFIG_H
#define GU_CONFIG_H 1

#include <stdio.h>
#include <sys/time.h>

#define MAX_CFG_LINE_LEN	128

struct cfg_Section {
  char *name;
};

struct cfg_InitConfig {
  void (*cmd)(void);
};

struct cfg_Args {
  int (*cmd)(char **, int);
};

struct cfg_PostConfig {
  void (*cmd)(void);
};

struct cfg_DoLine {
  char *tag;					/* The identifying tag */
  int tagl;						/* Length of tag comparison */
  char *(*cmd)(const char *);	/* The function to call, NULL to skip */
  char *section;				/* Section name in which it must be */
};

extern struct cfg_Section cfg_sections[];
extern struct cfg_DoLine cfg_linecmds[];
extern struct cfg_InitConfig cfg_init[];
extern struct cfg_Args cfg_args[];
extern struct cfg_PostConfig cfg_post[];

struct Cfg_Auth {
  struct Cfg_Auth *next;
  char *realm;
  char *upw;
};

struct RequestLine {
  struct RequestLine *next;
  char *line;
};

struct Cfg_Global {
  char *def_filename;			/* Filename to use if none given
								   (ie index.html) */
  char *def_saveto;				/* Save to file */
  char *fromstring;				/* From (email address) */
  struct Cfg_Auth *auth;		/* Authentication pwd list */
  char *saveroot;				/* save root */
  int d_mode, f_mode;			/* directory & file creation modes */
  char *trans_from, *trans_to;	/* Translate from/to when creating files */
  int def_depth;				/* Default depth */
  int def_flags;				/* Default flags */
  char *workfile;
  struct timeval wait;			/* Time to wait between grabs */
  struct RequestLine *shead;	/* Additional lines to send in request */
};

extern struct Cfg_Global cfg_global;

struct TmpList {
  struct TmpList *next, *prev;
  char *str;
};

void ReadConfigFile(char *);
void InitConfig();
int GetConfigArg(char **);
void GetArgs(char **);
void PostConfig(void);

void cfg_global_init(void);
int rargs_global(char **, int);
void cfg_global_post(void);

/* Config-lines functions */

char *cfg_cmd_include(const char *);
char *cfg_cmd_delay(const char *);
char *cfg_cmd_email(const char *);
char *cfg_cmd_saveroot(const char *);
char *cfg_cmd_dirmode(const char *);
char *cfg_cmd_filemode(const char *);
char *cfg_cmd_translate(const char *);
char *cfg_cmd_retry(const char *);
char *cfg_cmd_scan(const char *);
char *cfg_cmd_stayinhost(const char *);
char *cfg_cmd_nonexists(const char *);

char *cfg_cmd_auth(const char *);
char *cfg_cmd_requestline(const char *);
char *cfg_cmd_depth(const char *line);
/* char *cfg_cmd_addhead(const char *); */
char *cfg_cmd_ifmodified(const char *);
char *cfg_cmd_savehead(const char *);


#endif
